ToLog

Trait ToLog 

pub trait ToLog {
    // Required method
    fn to_log(&self, contract: H160) -> Log;
}
Implementation of this trait should not be written manually, instead use crate::ToLog proc macros.

See also evm_coder_procedural::ToLog, solidity docs on events

Required Methods

fn to_log(&self, contract: H160) -> Log

Convert event to ethereum::Log. Because event by itself doesn’t contains current contract address, it should be specified manually.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors